==> pvfs-1.1-9.tgz: pvfs-1.1/mgr/fslist.c <==

/*
/* fslist.c copyright (c) 1996 Rob Ross, all rights reserved.
/*/

/*
/* FSLIST.C - functions to handle the creation and modification of 
/* lists of filesystem information
/*
/* This is built on top of the llist.[ch] files
/*
/*/

/*
 * $Log: fslist.c,v $
 * Revision 1.4  1998/02/16 19:19:35  rbross
 * Newt patches
 *
 * Revision 1.3  1997/11/11 19:16:03  rbross
 * added fslist_dump() and fs_dump()
 *
 * Revision 1.2  1997/01/20 22:30:13  rbross
 * removed redundant call to flist_cleanup
 *
 * Revision 1.1  1996/11/21 21:18:37  rbross
 * Initial revision
 *
/*/

#include <stdlib.h>
#include <fslist.h>

static char fslist_c[] = "$Header: /projects/pvfs/pvfs-working/mgr/RCS/fslist.c,v 1.4 1998/02/16 19:19:35 rbross Exp $";

/* prototypes for internal functions */
static int fs_ino_cmp(void *key, void *fs_p);
static void fs_free(void * fs_p);

fslist_p fslist_new(void)
{
	return(llist_new());
}

int fs_add(fslist_p fsl_p, fsinfo_p fs_p)
{
	fs_p->fl_p = flist_new(); /* get new file list */
	return(llist_add(fsl_p, (void *) fs_p));
}

fsinfo_p fs_search(fslist_p fsl_p, ino_t fs_ino)
{
	return((fsinfo_p) llist_search(fsl_p, (void *) fs_ino, fs_ino_cmp));
}

int fs_rem(fslist_p fsl_p, ino_t fs_ino)
{
	fsinfo_p fs_p;
	
	fs_p = (fsinfo_p) llist_rem(fsl_p, (void *)fs_ino, fs_ino_cmp);
	if (fs_p) {
		fs_free(fs_p);
		return(0);
	}
	return(-1);
}

int forall_fs(fslist_p fsl_p, int (*fn)(void *))
{
	return(llist_doall(fsl_p, fn));
}

int fslist_dump(fslist_p fsl_p)
{
	return(forall_fs(fsl_p, fs_dump));
}

int fs_dump(void *v_p)
{
	fsinfo_p fs_p = (fsinfo_p) v_p;

	printf("fs_ino: %d\nnr_iods: %d\n", fs_p->fs_ino, fs_p->nr_iods);
	flist_dump(fs_p->fl_p);
	return(0);
}

void fslist_cleanup(fslist_p fsl_p)
{
	llist_free(fsl_p, fs_free);
}

static int fs_ino_cmp(void *key, void *fs_p)
{
	if (fs_p && (ino_t) key == ((fsinfo_p) fs_p)->fs_ino) return(0);
	else return(1);
}

static void fs_free(void * fs_p)
{
	flist_cleanup(((fsinfo_p) fs_p)->fl_p);
	free((fsinfo_p) fs_p);
}

==> pvfs-1.3.2.tgz: pvfs-1.3.2/mgr/fslist.c <==

/*
/* fslist.c copyright (c) 1996 Rob Ross, all rights reserved.
/*/

/*
/* FSLIST.C - functions to handle the creation and modification of 
/* lists of filesystem information
/*
/* This is built on top of the llist.[ch] files
/*
/*/

/*
 * $Log: fslist.c,v $
 * Revision 1.5  1999/06/17 15:40:21  rbross
 * *** empty log message ***
 *
 * Revision 1.4  1998/02/16 19:19:35  rbross
 * Newt patches
 *
 * Revision 1.3  1997/11/11 19:16:03  rbross
 * added fslist_dump() and fs_dump()
 *
 * Revision 1.2  1997/01/20 22:30:13  rbross
 * removed redundant call to flist_cleanup
 *
 * Revision 1.1  1996/11/21 21:18:37  rbross
 * Initial revision
 *
/*/

#include <stdlib.h>
#include <fslist.h>
#include <debug.h>

static char fslist_c[] = "$Header: /projects/pvfs/pvfs-working/mgr/RCS/fslist.c,v 1.5 1999/06/17 15:40:21 rbross Exp $";

/* prototypes for internal functions */
static int fs_ino_cmp(void *key, void *fs_p);
static void fs_free(void * fs_p);

fslist_p fslist_new(void)
{
	return(llist_new());
}

int fs_add(fslist_p fsl_p, fsinfo_p fs_p)
{
	fs_p->fl_p = flist_new(); /* get new file list */
	return(llist_add(fsl_p, (void *) fs_p));
}

fsinfo_p fs_search(fslist_p fsl_p, ino_t fs_ino)
{
	return((fsinfo_p) llist_search(fsl_p, (void *) fs_ino, fs_ino_cmp));
}

int fs_rem(fslist_p fsl_p, ino_t fs_ino)
{
	fsinfo_p fs_p;
	
	fs_p = (fsinfo_p) llist_rem(fsl_p, (void *)fs_ino, fs_ino_cmp);
	if (fs_p) {
		fs_free(fs_p);
		return(0);
	}
	return(-1);
}

int forall_fs(fslist_p fsl_p, int (*fn)(void *))
{
	return(llist_doall(fsl_p, fn));
}

int fslist_dump(fslist_p fsl_p)
{
	return(forall_fs(fsl_p, fs_dump));
}

int fs_dump(void *v_p)
{
	fsinfo_p fs_p = (fsinfo_p) v_p;

	LOG2("fs_ino: %d\nnr_iods: %d\n", fs_p->fs_ino, fs_p->nr_iods);
	flist_dump(fs_p->fl_p);
	return(0);
}

void fslist_cleanup(fslist_p fsl_p)
{
	llist_free(fsl_p, fs_free);
}

static int fs_ino_cmp(void *key, void *fs_p)
{
	if (fs_p && (ino_t) key == ((fsinfo_p) fs_p)->fs_ino) return(0);
	else return(1);
}

static void fs_free(void * fs_p)
{
	flist_cleanup(((fsinfo_p) fs_p)->fl_p);
	free((fsinfo_p) fs_p);
}
